@@ -53,9 +53,9 @@ from selenium.common.exceptions import (
 
 
 class ExceptionMapping:
-    """
-    :Maps each errorcode in ErrorCode object to corresponding exception
-    Please refer to https://www.w3.org/TR/webdriver2/#errors for w3c specification
+    """Maps each errorcode in ErrorCode object to corresponding exception.
+
+    Please refer to https://www.w3.org/TR/webdriver2/#errors for w3c specification.
     """
 
     NO_SUCH_ELEMENT = NoSuchElementException
@@ -143,14 +143,14 @@ class ErrorHandler:
     """Handles errors returned by the WebDriver server."""
 
     def check_response(self, response: dict[str, Any]) -> None:
-        """Checks that a JSON response from the WebDriver does not have an
-        error.
+        """Check that a JSON response from the WebDriver does not have an error.
 
-        :Args:
-         - response - The JSON response from the WebDriver server as a dictionary
-           object.
+        Args:
+            response: The JSON response from the WebDriver server as a dictionary
+                object.
 
-        :Raises: If the response contains an error message.
+        Raises:
+            WebDriverException: If the response contains an error message.
         """
         status = response.get("status", None)
         if not status or status == ErrorCode.SUCCESS:
