@@ -15,12 +15,20 @@
 # specific language governing permissions and limitations
 # under the License.
 
+from __future__ import annotations
+
 from hashlib import md5 as md5_hash
+from typing import TYPE_CHECKING
 
 from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.command import Command
 
+if TYPE_CHECKING:
+    # we only import these when the module is analyzed for type annotations
+    # to avoid a circular import when it is run normally
+    from selenium.webdriver.remote.webelement import WebElement
+
 
 class ShadowRoot:
     # TODO: We should look and see  how we can create a search context like Java/.NET
@@ -44,7 +52,7 @@ class ShadowRoot:
     def id(self) -> str:
         return self._id
 
-    def find_element(self, by: str = By.ID, value: str = None):
+    def find_element(self, by: str = By.ID, value: str | None = None) -> WebElement:
         """Find an element inside a shadow root given a By strategy and locator.
 
         Args:
@@ -57,7 +65,6 @@ class ShadowRoot:
                 - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
                 - By.LINK_TEXT: Locate a link element by its exact text.
                 - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
-                - RelativeBy: Locate elements relative to a specified root element.
             value: The locator value to use with the specified `by` strategy.
 
         Returns:
@@ -80,7 +87,7 @@ class ShadowRoot:
 
         return self._execute(Command.FIND_ELEMENT_FROM_SHADOW_ROOT, {"using": by, "value": value})["value"]
 
-    def find_elements(self, by: str = By.ID, value: str = None) -> list:
+    def find_elements(self, by: str = By.ID, value: str | None = None) -> list[WebElement]:
         """Find elements inside a shadow root given a By strategy and locator.
 
         Args:
@@ -93,7 +100,6 @@ class ShadowRoot:
                 - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
                 - By.LINK_TEXT: Locate a link element by its exact text.
                 - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
-                - RelativeBy: Locate elements relative to a specified root element.
             value: The locator value to use with the specified `by` strategy.
 
         Returns:
