@@ -14,6 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+
 from __future__ import annotations
 
 import os
@@ -24,17 +25,14 @@ from abc import ABCMeta
 from base64 import b64decode, encodebytes
 from hashlib import md5 as md5_hash
 from io import BytesIO
-from typing import List
 
 from selenium.common.exceptions import JavascriptException, WebDriverException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.utils import keys_to_typing
+from selenium.webdriver.remote.command import Command
+from selenium.webdriver.remote.shadowroot import ShadowRoot
 
-from .command import Command
-from .shadowroot import ShadowRoot
-
-# TODO: When moving to supporting python 3.9 as the minimum version we can
-# use built in importlib_resources.files.
+# TODO: Use built in importlib_resources.files.
 getAttribute_js = None
 isDisplayed_js = None
 
@@ -66,7 +64,7 @@ class WebElement(BaseWebElement):
     All method calls will do a freshness check to ensure that the element
     reference is still valid.  This essentially determines whether the
     element is still attached to the DOM.  If this test fails, then an
-    ``StaleElementReferenceException`` is thrown, and all future calls to this
+    `StaleElementReferenceException` is thrown, and all future calls to this
     instance will fail.
     """
 
@@ -83,15 +81,13 @@ class WebElement(BaseWebElement):
 
     @property
     def tag_name(self) -> str:
-        """This element's ``tagName`` property.
+        """This element's `tagName` property.
 
         Returns:
-        --------
-        str : The tag name of the element.
+            The tag name of the element.
 
         Example:
-        --------
-        >>> element = driver.find_element(By.ID, "foo")
+            element = driver.find_element(By.ID, "foo")
         """
         return self._execute(Command.GET_ELEMENT_TAG_NAME)["value"]
 
@@ -100,13 +96,11 @@ class WebElement(BaseWebElement):
         """The text of the element.
 
         Returns:
-        --------
-        str : The text of the element.
+            The text of the element.
 
         Example:
-        --------
-        >>> element = driver.find_element(By.ID, "foo")
-        >>> print(element.text)
+            element = driver.find_element(By.ID, "foo")
+            print(element.text)
         """
         return self._execute(Command.GET_ELEMENT_TEXT)["value"]
 
@@ -114,9 +108,8 @@ class WebElement(BaseWebElement):
         """Clicks the element.
 
         Example:
-        --------
-        >>> element = driver.find_element(By.ID, "foo")
-        >>> element.click()
+            element = driver.find_element(By.ID, "foo")
+            element.click()
         """
         self._execute(Command.CLICK_ELEMENT)
 
@@ -124,9 +117,8 @@ class WebElement(BaseWebElement):
         """Submits a form.
 
         Example:
-        --------
-        >>> form = driver.find_element(By.NAME, "login")
-        >>> form.submit()
+            form = driver.find_element(By.NAME, "login")
+            form.submit()
         """
         script = (
             "/* submitForm */var form = arguments[0];\n"
@@ -149,27 +141,22 @@ class WebElement(BaseWebElement):
         """Clears the text if it's a text entry element.
 
         Example:
-        --------
-        >>> text_field = driver.find_element(By.NAME, "username")
-        >>> text_field.clear()
+            text_field = driver.find_element(By.NAME, "username")
+            text_field.clear()
         """
         self._execute(Command.CLEAR_ELEMENT)
 
     def get_property(self, name) -> str | bool | WebElement | dict:
         """Gets the given property of the element.
 
-        Parameters:
-        -----------
-        name : str
-            - Name of the property to retrieve.
+        Args:
+            name: Name of the property to retrieve.
 
         Returns:
-        -------
-        str | bool | WebElement | dict : The value of the property.
+            The value of the property.
 
         Example:
-        -------
-        >>> text_length = target_element.get_property("text_length")
+            text_length = target_element.get_property("text_length")
         """
         try:
             return self._execute(Command.GET_ELEMENT_PROPERTY, {"name": name})["value"]
@@ -178,22 +165,19 @@ class WebElement(BaseWebElement):
             return self.parent.execute_script("return arguments[0][arguments[1]]", self, name)
 
     def get_dom_attribute(self, name) -> str:
-        """Gets the given attribute of the element. Unlike
-        :func:`~selenium.webdriver.remote.BaseWebElement.get_attribute`, this
-        method only returns attributes declared in the element's HTML markup.
+        """Get the HTML attribute value (not reflected properties) of the element.
 
-        Parameters:
-        -----------
-        name : str
-            - Name of the attribute to retrieve.
+        Returns only attributes declared in the element's HTML markup, unlike
+        `selenium.webdriver.remote.BaseWebElement.get_attribute`.
+
+        Args:
+            name: Name of the attribute to retrieve.
 
         Returns:
-        -------
-        str : The value of the attribute.
+            The value of the attribute.
 
         Example:
-        -------
-        >>> text_length = target_element.get_dom_attribute("class")
+            text_length = target_element.get_dom_attribute("class")
         """
         return self._execute(Command.GET_ELEMENT_ATTRIBUTE, {"name": name})["value"]
 
@@ -214,19 +198,15 @@ class WebElement(BaseWebElement):
         use :func:`~selenium.webdriver.remote.BaseWebElement.get_dom_attribute` or
         :func:`~selenium.webdriver.remote.BaseWebElement.get_property` methods respectively.
 
-        Parameters:
-        -----------
-        name : str
-            - Name of the attribute/property to retrieve.
+        Args:
+            name: Name of the attribute/property to retrieve.
 
         Returns:
-        -------
-        str | bool | None : The value of the attribute/property.
+            The value of the attribute/property.
 
         Example:
-        --------
-        >>> # Check if the "active" CSS class is applied to an element.
-        >>> is_active = "active" in target_element.get_attribute("class")
+            # Check if the "active" CSS class is applied to an element.
+            is_active = "active" in target_element.get_attribute("class")
         """
         if getAttribute_js is None:
             _load_js()
@@ -238,14 +218,11 @@ class WebElement(BaseWebElement):
     def is_selected(self) -> bool:
         """Returns whether the element is selected.
 
-        Example:
-        --------
-        >>> is_selected = element.is_selected()
+        This method is generally used on checkboxes, options in a select
+        and radio buttons.
 
-        Notes:
-        ------
-            - This method is generally used on checkboxes, options in a select
-            and radio buttons.
+        Example:
+            is_selected = element.is_selected()
         """
         return self._execute(Command.IS_ELEMENT_SELECTED)["value"]
 
@@ -253,39 +230,33 @@ class WebElement(BaseWebElement):
         """Returns whether the element is enabled.
 
         Example:
-        --------
-        >>> is_enabled = element.is_enabled()
+            is_enabled = element.is_enabled()
         """
         return self._execute(Command.IS_ELEMENT_ENABLED)["value"]
 
     def send_keys(self, *value: str) -> None:
         """Simulates typing into the element.
 
-        Parameters:
-        -----------
-        value : str
-            - A string for typing, or setting form fields.  For setting
-            file inputs, this could be a local file path.
+        Use this to send simple key events or to fill out form fields.
+        This can also be used to set file inputs.
 
-        Notes:
-        ------
-            - Use this to send simple key events or to fill out form fields
-            - This can also be used to set file inputs.
+        Args:
+            value: A string for typing, or setting form fields. For setting
+                file inputs, this could be a local file path.
 
         Examples:
-        --------
-        To send a simple key event::
-        >>> form_textfield = driver.find_element(By.NAME, "username")
-        >>> form_textfield.send_keys("admin")
+            To send a simple key event::
 
-        or to set a file input field::
-        >>> file_input = driver.find_element(By.NAME, "profilePic")
-        >>> file_input.send_keys("path/to/profilepic.gif")
-        >>> # Generally it's better to wrap the file path in one of the methods
-        >>> # in os.path to return the actual path to support cross OS testing.
-        >>> # file_input.send_keys(os.path.abspath("path/to/profilepic.gif"))
-        >>> # When using Cygwin, the path need to be provided in Windows format.
-        >>> # file_input.send_keys(f"C:/cygwin{os.path.abspath('path/to/profilepic.gif').replace('/', '\\')}")
+            form_textfield = driver.find_element(By.NAME, "username")
+            form_textfield.send_keys("admin")
+
+            or to set a file input field::
+
+            file_input = driver.find_element(By.NAME, "profilePic")
+            file_input.send_keys("path/to/profilepic.gif")
+            # Generally it's better to wrap the file path in one of the methods
+            # in os.path to return the actual path to support cross OS testing.
+            # file_input.send_keys(os.path.abspath("path/to/profilepic.gif"))
         """
         # transfer file to another machine only if remote driver is used
         # the same behaviour as for java binding
@@ -308,23 +279,19 @@ class WebElement(BaseWebElement):
 
     @property
     def shadow_root(self) -> ShadowRoot:
-        """Returns a shadow root of the element if there is one or an error.
-        Only works from Chromium 96, Firefox 96, and Safari 16.4 onwards.
+        """Get the shadow root attached to this element if present (Chromium, Firefox, Safari).
 
         Returns:
-        -------
-        ShadowRoot : object
+            The ShadowRoot object.
 
         Raises:
-        -------
-        NoSuchShadowRoot - if no shadow root was attached to element
+            NoSuchShadowRoot: If no shadow root was attached to element.
 
         Example:
-        --------
-        >>> try:
-        ...     shadow_root = element.shadow_root
-        >>> except NoSuchShadowRoot:
-        ...     print("No shadow root attached to element")
+            try:
+                shadow_root = element.shadow_root
+            except NoSuchShadowRoot:
+                print("No shadow root attached to element")
         """
         return self._execute(Command.GET_SHADOW_ROOT)["value"]
 
@@ -333,8 +300,7 @@ class WebElement(BaseWebElement):
         """Whether the element is visible to a user.
 
         Example:
-        --------
-        >>> is_displayed = element.is_displayed()
+            is_displayed = element.is_displayed()
         """
         # Only go into this conditional for browsers that don't use the atom themselves
         if isDisplayed_js is None:
@@ -343,18 +309,17 @@ class WebElement(BaseWebElement):
 
     @property
     def location_once_scrolled_into_view(self) -> dict:
-        """THIS PROPERTY MAY CHANGE WITHOUT WARNING. Use this to discover where
-        on the screen an element is so that we can click it. This method should
-        cause the element to be scrolled into view.
+        """Get the element's location on screen after scrolling it into view.
+
+        This may change without warning and scrolls the element into view
+        before calculating coordinates for clicking purposes.
 
         Returns:
-        --------
-        dict: the top lefthand corner location on the screen, or zero
+            The top lefthand corner location on the screen, or zero
             coordinates if the element is not visible.
 
         Example:
-        --------
-        >>> loc = element.location_once_scrolled_into_view
+            loc = element.location_once_scrolled_into_view
         """
         old_loc = self._execute(
             Command.W3C_EXECUTE_SCRIPT,
@@ -367,49 +332,41 @@ class WebElement(BaseWebElement):
 
     @property
     def size(self) -> dict:
-        """The size of the element.
+        """Get the size of the element.
 
         Returns:
-        --------
-        dict: The width and height of the element.
+            The width and height of the element.
 
         Example:
-        --------
-        >>> size = element.size
+            size = element.size
         """
         size = self._execute(Command.GET_ELEMENT_RECT)["value"]
         new_size = {"height": size["height"], "width": size["width"]}
         return new_size
 
     def value_of_css_property(self, property_name) -> str:
-        """The value of a CSS property.
+        """Get the value of a CSS property.
 
-        Parameters:
-        -----------
-        property_name : str
-            - The name of the CSS property to get the value of.
+        Args:
+            property_name: The name of the CSS property to get the value of.
 
         Returns:
-        --------
-        str : The value of the CSS property.
+            The value of the CSS property.
 
         Example:
-        --------
-        >>> value = element.value_of_css_property("color")
+            value = element.value_of_css_property("color")
         """
         return self._execute(Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY, {"propertyName": property_name})["value"]
 
     @property
     def location(self) -> dict:
-        """The location of the element in the renderable canvas.
+        """Get the location of the element in the renderable canvas.
 
         Returns:
-        --------
-        dict: The x and y coordinates of the element.
+            The x and y coordinates of the element.
 
         Example:
-        --------
-        >>> loc = element.location
+            loc = element.location
         """
         old_loc = self._execute(Command.GET_ELEMENT_RECT)["value"]
         new_loc = {"x": round(old_loc["x"]), "y": round(old_loc["y"])}
@@ -417,93 +374,78 @@ class WebElement(BaseWebElement):
 
     @property
     def rect(self) -> dict:
-        """A dictionary with the size and location of the element.
+        """Get the size and location of the element.
 
         Returns:
-        --------
-        dict: The size and location of the element.
+            A dictionary with size and location of the element.
 
         Example:
-        --------
-        >>> rect = element.rect
+            rect = element.rect
         """
         return self._execute(Command.GET_ELEMENT_RECT)["value"]
 
     @property
     def aria_role(self) -> str:
-        """Returns the ARIA role of the current web element.
+        """Get the ARIA role of the current web element.
 
         Returns:
-        --------
-        str : The ARIA role of the element.
+            The ARIA role of the element.
 
         Example:
-        --------
-        >>> role = element.aria_role
+            role = element.aria_role
         """
         return self._execute(Command.GET_ELEMENT_ARIA_ROLE)["value"]
 
     @property
     def accessible_name(self) -> str:
-        """Returns the ARIA Level of the current webelement.
+        """Get the ARIA Level of the current webelement.
 
         Returns:
-        --------
-        str : The ARIA Level of the element.
+            The ARIA Level of the element.
 
         Example:
-        --------
-        >>> name = element.accessible_name
+            name = element.accessible_name
         """
         return self._execute(Command.GET_ELEMENT_ARIA_LABEL)["value"]
 
     @property
     def screenshot_as_base64(self) -> str:
-        """Gets the screenshot of the current element as a base64 encoded
-        string.
+        """Get a base64-encoded screenshot of the current element.
 
         Returns:
-        --------
-        str : The screenshot of the element as a base64 encoded string.
+            The screenshot of the element as a base64 encoded string.
 
         Example:
-        --------
-        >>> img_b64 = element.screenshot_as_base64
+            img_b64 = element.screenshot_as_base64
         """
         return self._execute(Command.ELEMENT_SCREENSHOT)["value"]
 
     @property
     def screenshot_as_png(self) -> bytes:
-        """Gets the screenshot of the current element as a binary data.
+        """Get the screenshot of the current element as a binary data.
 
         Returns:
-        --------
-        bytes : The screenshot of the element as binary data.
+            The screenshot of the element as binary data.
 
         Example:
-        --------
-        >>> element_png = element.screenshot_as_png
+            element_png = element.screenshot_as_png
         """
         return b64decode(self.screenshot_as_base64.encode("ascii"))
 
     def screenshot(self, filename) -> bool:
-        """Saves a screenshot of the current element to a PNG image file.
-        Returns False if there is any IOError, else returns True. Use full
-        paths in your filename.
+        """Save a PNG screenshot of the current element to a file.
+
+        Use full paths in your filename.
+
+        Args:
+            filename: The full path you wish to save your screenshot to. This
+                should end with a `.png` extension.
 
         Returns:
-        --------
-        bool : True if the screenshot was saved successfully, False otherwise.
+            True if the screenshot was saved successfully, False otherwise.
 
-        Parameters:
-        -----------
-        filename : str
-            The full path you wish to save your screenshot to. This
-            should end with a `.png` extension.
-
-        Element:
-        --------
-        >>> element.screenshot("/Screenshots/foo.png")
+        Example:
+            element.screenshot("/Screenshots/foo.png")
         """
         if not filename.lower().endswith(".png"):
             warnings.warn(
@@ -522,27 +464,24 @@ class WebElement(BaseWebElement):
 
     @property
     def parent(self):
-        """Internal reference to the WebDriver instance this element was found
-        from.
+        """Get the WebDriver instance this element was found from.
 
         Example:
-        --------
-        >>> element = driver.find_element(By.ID, "foo")
-        >>> parent_element = element.parent
+            element = driver.find_element(By.ID, "foo")
+            parent_element = element.parent
         """
         return self._parent
 
     @property
     def id(self) -> str:
-        """Internal ID used by selenium.
+        """Get the ID used by selenium.
 
         This is mainly for internal use. Simple use cases such as checking if 2
         webelements refer to the same element, can be done using ``==``::
 
         Example:
-        --------
-        >>> if element1 == element2:
-        ...     print("These 2 are equal")
+            if element1 == element2:
+                print("These 2 are equal")
         """
         return self._id
 
@@ -556,77 +495,62 @@ class WebElement(BaseWebElement):
     def _execute(self, command, params=None):
         """Executes a command against the underlying HTML element.
 
-        Parameters:
-        -----------
-        command : any
-            The name of the command to _execute as a string.
-
-        params : dict
-            A dictionary of named Parameters to send with the command.
+        Args:
+            command: The name of the command to _execute as a string.
+            params: A dictionary of named Parameters to send with the command.
 
         Returns:
-        -------
-          The command's JSON response loaded into a dictionary object.
+            The command's JSON response loaded into a dictionary object.
         """
         if not params:
             params = {}
         params["id"] = self._id
         return self._parent.execute(command, params)
 
-    def find_element(self, by=By.ID, value=None) -> WebElement:
+    def find_element(self, by: str = By.ID, value: str | None = None) -> WebElement:
         """Find an element given a By strategy and locator.
 
-        Parameters:
-        -----------
-        by : selenium.webdriver.common.by.By
-            The locating strategy to use. Default is `By.ID`. Supported values include:
-            - By.ID: Locate by element ID.
-            - By.NAME: Locate by the `name` attribute.
-            - By.XPATH: Locate by an XPath expression.
-            - By.CSS_SELECTOR: Locate by a CSS selector.
-            - By.CLASS_NAME: Locate by the `class` attribute.
-            - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
-            - By.LINK_TEXT: Locate a link element by its exact text.
-            - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
-            - RelativeBy: Locate elements relative to a specified root element.
-
-        Example:
-        --------
-        element = driver.find_element(By.ID, 'foo')
+        Args:
+            by: The locating strategy to use. Default is `By.ID`. Supported values include:
+                - By.ID: Locate by element ID.
+                - By.NAME: Locate by the `name` attribute.
+                - By.XPATH: Locate by an XPath expression.
+                - By.CSS_SELECTOR: Locate by a CSS selector.
+                - By.CLASS_NAME: Locate by the `class` attribute.
+                - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
+                - By.LINK_TEXT: Locate a link element by its exact text.
+                - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
+            value: The locator value to use with the specified `by` strategy.
 
         Returns:
-        -------
-        WebElement
             The first matching `WebElement` found on the page.
+
+        Example:
+            element = driver.find_element(By.ID, "foo")
         """
         by, value = self._parent.locator_converter.convert(by, value)
         return self._execute(Command.FIND_CHILD_ELEMENT, {"using": by, "value": value})["value"]
 
-    def find_elements(self, by=By.ID, value=None) -> List[WebElement]:
+    def find_elements(self, by: str = By.ID, value: str | None = None) -> list[WebElement]:
         """Find elements given a By strategy and locator.
 
-        Parameters:
-        -----------
-        by : selenium.webdriver.common.by.By
-            The locating strategy to use. Default is `By.ID`. Supported values include:
-            - By.ID: Locate by element ID.
-            - By.NAME: Locate by the `name` attribute.
-            - By.XPATH: Locate by an XPath expression.
-            - By.CSS_SELECTOR: Locate by a CSS selector.
-            - By.CLASS_NAME: Locate by the `class` attribute.
-            - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
-            - By.LINK_TEXT: Locate a link element by its exact text.
-            - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
-            - RelativeBy: Locate elements relative to a specified root element.
-
-        Example:
-        --------
-        >>> element = driver.find_elements(By.ID, "foo")
+        Args:
+            by: The locating strategy to use. Default is `By.ID`. Supported values include:
+                - By.ID: Locate by element ID.
+                - By.NAME: Locate by the `name` attribute.
+                - By.XPATH: Locate by an XPath expression.
+                - By.CSS_SELECTOR: Locate by a CSS selector.
+                - By.CLASS_NAME: Locate by the `class` attribute.
+                - By.TAG_NAME: Locate by the tag name (e.g., "input", "button").
+                - By.LINK_TEXT: Locate a link element by its exact text.
+                - By.PARTIAL_LINK_TEXT: Locate a link element by partial text match.
+            value: The locator value to use with the specified `by` strategy.
 
         Returns:
-        -------
-        List[WebElement]
-            list of `WebElements` matching locator strategy found on the page.
+            List of `WebElements` matching locator strategy found on the page.
+
+        Example:
+            element = driver.find_elements(By.ID, "foo")
         """
         by, value = self._parent.locator_converter.convert(by, value)
         return self._execute(Command.FIND_CHILD_ELEMENTS, {"using": by, "value": value})["value"]
